@@ -1,4 +1,4 @@
-/* $Id: sysdeps.h,v 1.31 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: sysdeps.h,v 1.38 2005/08/02 09:47:17 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,7 @@
 
 #include <glibtop.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SYSDEPS_FEATURES	0
 #define GLIBTOP_SYSDEPS_CPU		1
@@ -51,20 +51,18 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SYSDEPS_FSUSAGE		20
 #define GLIBTOP_SYSDEPS_NETLOAD		21
 #define GLIBTOP_SYSDEPS_PPP		22
+#define GLIBTOP_SYSDEPS_NETLIST		23
+#define GLIBTOP_SYSDEPS_PROC_OPEN_FILES	24
 
-#define GLIBTOP_MAX_SYSDEPS		23
+#define GLIBTOP_MAX_SYSDEPS		25
 
 #define GLIBTOP_SYSDEPS_ALL		((1 << GLIBTOP_MAX_SYSDEPS) - 1)
 
-typedef void (*glibtop_init_func_t) (glibtop *);
-extern glibtop_init_func_t _glibtop_init_hook_s [];
-extern glibtop_init_func_t _glibtop_init_hook_p [];
-
 typedef struct _glibtop_sysdeps	glibtop_sysdeps;
 
 struct _glibtop_sysdeps
 {
-	u_int64_t flags,
+	guint64 flags,
 		features,		/* server features	*/
 		cpu,			/* glibtop_cpu		*/
 		mem,			/* glibtop_mem		*/
@@ -84,27 +82,18 @@ struct _glibtop_sysdeps
 		proc_segment,		/* glibtop_proc_segment	*/
 		proc_args,		/* glibtop_proc_args	*/
 		proc_map,		/* glibtop_proc_map	*/
+		proc_open_files,	/* glibtop_proc_open_files */
 		mountlist,		/* glibtop_mountlist	*/
 		fsusage,		/* glibtop_fsusage	*/
+		netlist,		/* glibtop_netlist	*/
 		netload,		/* glibtop_netload	*/
 		ppp;			/* glibtop_ppp		*/
 };
 
-#define glibtop_get_sysdeps(sysdeps)	glibtop_get_sysdeps_r(glibtop_global_server,sysdeps)
-
+void glibtop_get_sysdeps (glibtop_sysdeps *buf);
 void glibtop_get_sysdeps_r (glibtop *server, glibtop_sysdeps *buf);
 
-#ifdef GLIBTOP_NAMES
 
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_sysdeps [];
-extern const unsigned glibtop_types_sysdeps [];
-extern const char *glibtop_labels_sysdeps [];
-extern const char *glibtop_descriptions_sysdeps [];
-
-#endif
-
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
